Coverage for denofo/choices.py: 100%

1 from enum import Enum

2

3

4 class AnnotGenomeChoices(str, Enum):

5 abInitio = "ab initio approach"

6 homology = "homology-based approach"

7 unknown = "unknown"

8

9

10 class ORFChoices(str, Enum):

11 noORF = "no ORF"

12 allORF = "all ORF"

13 highestKoz = "highest Kozac"

14 longestORF = "longest ORF"

15 firstORF = "start first ORF"

16 long_5_3_ORF = "long 5` 3` ORF"

17 CUSTOM = "custom choice"

18

19

20 class GeneticContextChoices(str, Enum):

21 intergenic = "intergenic"

22 antisense = "antisense"

23 intronic = "intronic"

24 overlap_gene = "overlap gene"

25 CUSTOM = "custom choice"

26

27

28 class InputDataChoices(str, Enum):

29 ANNOT_GENOME = "annotated genome"

30 TRANSCRIPTOME = "transcriptome"

31 CUSTOM = "custom choice"

32

33

34 class TaxSpecificityChoices(str, Enum):

35 conditSpecif = "tissue/condition-specific"

36 speciesSpecif = "species-specific"

37 lineageSpecif = "lineage-specific"

38

39

40 class HomologyDBChoices(str, Enum):

41 NCBINR = "NCBI NR"

42 REFSEQ = "RefSeq"

43 TrEMBL = "UniProtKB/TrEMBL"

44 SWISSPROT = "UniProtKB/Swiss-Prot"

45 ENA = "ENA (by EMBL-EBI)"

46 ENSEMBL = "Ensembl"

47 INTERPRO = "InterPro"

48 CUSTOM = "custom choice"

49

50

51 class ThresholdChoices(str, Enum):

52 EVALUE = "e-value"

53 COVERAGE = "coverage [%]"

54 CUSTOM = "custom choice"

55

56

57 class SeqTypeChoices(str, Enum):

58 PROT_SEQS = "protein sequences"

59 DNA = "DNA"

60 FRAME6 = "6-frame translation"

61 RNA = "RNA"

62 NCRNA = "ncRNAs"

63 TE = "transposable elements"

64 CUSTOM = "custom choice"

65

66

67 class DirectionChoices(str, Enum):

68 FORWARD = "forward"

69 ANY = "any direction"

70

71

72 class AnchorChoices(str, Enum):

73 GENEANCHOR = "gene anchors"

74 GENOMEALIGNMENT = "genome alignment"

75 CUSTOM = "custom choice"

76

77

78 class TranslationEvidenceChoices(str, Enum):

79 MASS_SPEC = "mass spectrometry"

80 RIBO_PROFIL = "ribosome profiling"

81 PERIODICITY = "periodicity"

82 CUSTOM = "custom choice"